package Data::Object::Func::Integer;

use Data::Object 'Class';

extends 'Data::Object::Func';

# BUILD
# METHODS

1;

=encoding utf8

=head1 NAME

Data::Object::Func::Integer

=cut

=head1 ABSTRACT

Functions for Integer Data

=cut

=head1 SYNOPSIS

  use Data::Object::Func::Integer;

=cut

=head1 DESCRIPTION

Data::Object::Func::Integer is an abstract base class for function classes in
the Data::Object::Func::Integer space.

=cut
